@@ -27,7 +27,7 @@
 ;;
 ;;; Flags
 
-(advice-add #'eask-allow-error-p :override #'always)
+(advice-add #'eask-allow-error-p :override #'eask-always)
 
 ;;
 ;;; Handle options
@@ -59,8 +59,8 @@
 
 (eask-start
   ;; Preparation
-  (eask-with-archives '("gnu" "melpa")
-    (eask-package-install 'package-lint))
+  (eask-archive-install-packages '("gnu" "melpa")
+                                 'package-lint)
   (setq eask-lint-package--version (eask-package--version-string 'package-lint))
 
   ;; Start Linting
